@@ -22,14 +22,24 @@
 require_once "Centreon/Object/Object.php";
 
 /**
- * Used for interacting with dependencies
+ * Class
  *
+ * @class Centreon_Object_DependencyHostParent
+ * @description Used for interacting with dependencies
  */
 class Centreon_Object_DependencyHostParent extends Centreon_Object
 {
+    /** @var string */
     protected $table = "dependency_hostParent_relation";
+    /** @var string */
     protected $primaryKey = "dependency_dep_id";
 
+    /**
+     * @param int $hostId
+     *
+     * @return void
+     * @throws PDOException
+     */
     public function removeRelationLastHostDependency(int $hostId): void
     {
         $query = 'SELECT count(dependency_dep_id) AS nb_dependency , dependency_dep_id AS id
@@ -37,7 +47,7 @@ class Centreon_Object_DependencyHostParent extends Centreon_Object
               WHERE dependency_dep_id = (SELECT dependency_dep_id FROM dependency_hostParent_relation
                                          WHERE host_host_id = ?)
               GROUP BY dependency_dep_id';
-        $result = $this->getResult($query, array($hostId), "fetch");
+        $result = $this->getResult($query, [$hostId], "fetch");
 
         //is last parent
         if (isset($result['nb_dependency']) && $result['nb_dependency'] == 1) {
