@@ -19,7 +19,8 @@ export enum InputType {
   Custom = 10,
   Checkbox = 11,
   CheckboxGroup = 12,
-  List = 13
+  List = 13,
+  File = 14
 }
 
 interface FieldsTableGetRequiredProps {
@@ -37,8 +38,16 @@ export interface InputProps {
   autocomplete?: {
     creatable?: boolean;
     options: Array<SelectEntry>;
+    fullWidth?: boolean;
   };
-  change?: ({ setFieldValue, value }) => void;
+  change?: ({
+    setFieldValue,
+    value,
+    setFieldTouched,
+    setValues,
+    values,
+    setTouched
+  }) => void;
   checkbox?: {
     direction?: 'horizontal' | 'vertical';
     labelPlacement?: LabelPlacement;
@@ -46,14 +55,18 @@ export interface InputProps {
   };
   connectedAutocomplete?: {
     additionalConditionParameters: Array<ConditionsSearchParameter>;
-    decoder?;
-    disableSelectAll?: boolean;
+    chipColor?: string;
     endpoint?: string;
     filterKey?: string;
-    getOptionLabel?: (option) => string;
     getRenderedOptionText?: (option) => string | JSX.Element;
-    limitTags?: number;
-    optionProperty?: string;
+    decoder?;
+    limitTags: number;
+  };
+  file?: {
+    multiple?: boolean;
+    accept?: string;
+    maxFileSize?: number;
+    CustomDropZoneContent: ({ files }) => JSX.Element;
   };
   custom?: {
     Component: React.ComponentType<InputPropsWithoutGroup>;
@@ -78,7 +91,6 @@ export interface InputProps {
     className?: string;
     columns: Array<Omit<InputProps, 'group'>>;
     gridTemplateColumns?: string;
-    isColumnDirection?: boolean;
   };
   group: string;
   hideInput?: (values: FormikValues) => boolean;
@@ -107,6 +119,8 @@ export interface InputProps {
     multilineRows?: number;
     placeholder?: string;
     type?: string;
+    min?: number;
+    fullWidth?: boolean;
   };
   type: InputType;
 }
