@@ -1,5 +1,3 @@
-import { memo, useMemo } from 'react';
-
 import {
   BarRounded,
   BarStackHorizontal,
@@ -7,28 +5,28 @@ import {
 } from '@visx/shape';
 import { Text } from '@visx/text';
 import { equals, props } from 'ramda';
-
+import { memo, useMemo } from 'react';
 import { Tooltip } from '../../components';
 import { getValueByUnit } from '../common/utils';
-
 import { useGraphStyles } from './BarStack.styles';
 import { BarStackProps } from './models';
 import { useGraphAndLegend } from './useGraphAndLegend';
 
-interface Props extends Pick<
-  BarStackProps,
-  | 'data'
-  | 'displayValues'
-  | 'onSingleBarClick'
-  | 'unit'
-  | 'TooltipContent'
-  | 'tooltipProps'
-> {
-  colorScale;
+interface Props
+  extends Pick<
+    BarStackProps,
+    | 'data'
+    | 'displayValues'
+    | 'onSingleBarClick'
+    | 'unit'
+    | 'TooltipContent'
+    | 'tooltipProps'
+  > {
+  width: number;
   height: number;
   isVerticalBar: boolean;
+  colorScale;
   total: number;
-  width: number;
 }
 
 const Graph = ({
@@ -55,14 +53,14 @@ const Graph = ({
 
   const { barStackData, xScale, yScale, keys } = useGraphAndLegend({
     data,
+    width,
     height: normalizedHeight,
     isVerticalBar,
-    total,
-    width
+    total
   });
 
   return (
-    <svg height={normalizedHeight} width="100%">
+    <svg width="100%" height={normalizedHeight}>
       <BarStackComponent
         color={colorScale}
         data={[barStackData]}
@@ -95,8 +93,8 @@ const Graph = ({
 
               return (
                 <Tooltip
-                  classes={classes}
                   followCursor={false}
+                  classes={classes}
                   key={`bar-stack-${barStack.index}-${bar.index}`}
                   label={
                     TooltipContent && (
@@ -113,18 +111,18 @@ const Graph = ({
                 >
                   <g data-testid={bar.key} key={bar.key}>
                     <BarRounded
-                      bottom={isVerticalBar && isFirstBar}
+                      radius={8}
                       cursor={onSingleBarClick ? 'pointer' : 'default'}
                       fill={bar.color}
                       height={bar.height}
                       key={`bar-stack-${barStack.index}-${bar.index}`}
-                      left={!isVerticalBar && isFirstBar}
-                      radius={8}
-                      right={!isVerticalBar && isLastBar}
-                      top={isVerticalBar && isLastBar}
                       width={isVerticalBar ? bar.width - 10 : bar.width}
                       x={bar.x}
                       y={bar.y}
+                      left={!isVerticalBar && isFirstBar}
+                      right={!isVerticalBar && isLastBar}
+                      bottom={isVerticalBar && isFirstBar}
+                      top={isVerticalBar && isLastBar}
                       onMouseDown={click}
                     />
                     {displayValues && fitsInBar && (
