@@ -1,11 +1,10 @@
-import * as React from 'react';
-
 import {
-  TransitionProps as _TransitionProps,
-  TransitionActions
+  TransitionActions,
+  TransitionProps as _TransitionProps
 } from 'react-transition-group/Transition';
 
 import { Fade } from '@mui/material';
+import { CSSProperties, ReactNode } from 'react';
 
 type TransitionHandlerKeys =
   | 'onEnter'
@@ -22,12 +21,13 @@ type TransitionKeys =
   | 'addEndListener'
   | TransitionHandlerKeys;
 interface TransitionProps
-  extends TransitionActions, Partial<Pick<_TransitionProps, TransitionKeys>> {
-  style?: React.CSSProperties;
+  extends TransitionActions,
+    Partial<Pick<_TransitionProps, TransitionKeys>> {
+  style?: CSSProperties;
 }
 
 interface Props extends TransitionProps {
-  children?: React.ReactNode;
+  children?: ReactNode;
 }
 
 const Transition = ({ children, ...rest }: Props): JSX.Element => (
