@@ -4,7 +4,7 @@ import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
 
 const defaultCacheTime = 5 * 1_000;
 
-const client = new QueryClient({
+export const client = new QueryClient({
   defaultOptions: {
     queries: {
       gcTime: defaultCacheTime,
@@ -17,10 +17,13 @@ const client = new QueryClient({
 
 interface Props {
   children: ReactNode;
+  queryClient?: QueryClient;
 }
 
-const QueryProvider = ({ children }: Props): JSX.Element => (
-  <QueryClientProvider client={client}>{children}</QueryClientProvider>
+const QueryProvider = ({ children, queryClient }: Props): JSX.Element => (
+  <QueryClientProvider client={queryClient || client}>
+    {children}
+  </QueryClientProvider>
 );
 
 export default QueryProvider;
