@@ -15,11 +15,11 @@ import {
 
 const initialize = ({
   initialValues = simpleAccessRights,
-  loading = false,
-  link = 'link'
+  loading = false
 }): unknown => {
   const cancel = cy.stub();
   const save = cy.stub();
+  const change = cy.stub();
 
   cy.interceptAPIRequest({
     alias: 'getContacts',
@@ -47,10 +47,10 @@ const initialize = ({
               }}
               initialValues={initialValues}
               labels={labels}
-              link={link}
               loading={loading}
               roles={roles}
               submit={save}
+              onChange={change}
             />
           </Provider>
         </TestQueryProvider>
@@ -60,6 +60,7 @@ const initialize = ({
 
   return {
     cancel,
+    change,
     save
   };
 };
@@ -74,21 +75,12 @@ describe('Access rights', () => {
     cy.findByLabelText('Add a contact').should('be.visible');
     cy.findByTestId('add_role').should('be.disabled');
     cy.findByTestId('add').should('be.disabled');
-    cy.findByLabelText('Copy link').should('be.visible');
     cy.findByLabelText('Cancel').should('be.visible');
     cy.findByLabelText('Save').should('be.visible');
 
     cy.makeSnapshot();
   });
 
-  it('displays the access rights without link', () => {
-    initialize({ link: null });
-
-    cy.findByLabelText('Copy link').should('not.exist');
-
-    cy.makeSnapshot();
-  });
-
   it('displays the access rights with an empty list', () => {
     initialize({ initialValues: emptyAccessRights });
 
@@ -97,7 +89,7 @@ describe('Access rights', () => {
     cy.makeSnapshot();
   });
 
-  it('displays the access rights with an empty list', () => {
+  it('displays the access rights list', () => {
     initialize({});
 
     simpleAccessRights.forEach(({ name, email, isContactGroup, role }) => {
@@ -116,15 +108,15 @@ describe('Access rights', () => {
   it('displays a removed chip when the corresponding icon is clicked', () => {
     initialize({});
 
-    cy.findByTestId(`remove-Kathy Schmitt`).should(
+    cy.findByTestId('remove-Kathy Schmitt').should(
       'have.attr',
       'data-removed',
       'false'
     );
 
-    cy.findByTestId(`remove-Kathy Schmitt`).click();
+    cy.findByTestId('remove-Kathy Schmitt').click();
 
-    cy.findByTestId(`remove-Kathy Schmitt`).should(
+    cy.findByTestId('remove-Kathy Schmitt').should(
       'have.attr',
       'data-removed',
       'true'
@@ -137,18 +129,9 @@ describe('Access rights', () => {
   it('restores the contact when the contact is removed and the corresponding icon is clicked', () => {
     initialize({});
 
-    cy.findByTestId(`remove-Kathy Schmitt`).click();
+    cy.findByTestId('remove-Kathy Schmitt').click();
 
-    cy.findByTestId(`remove-Kathy Schmitt`).should(
-      'have.attr',
-      'data-removed',
-      'true'
-    );
-    cy.contains(labels.list.removed).should('be.visible');
-
-    cy.findByTestId(`remove-Kathy Schmitt`).click();
-
-    cy.findByTestId(`remove-Kathy Schmitt`).should(
+    cy.findByTestId('remove-Kathy Schmitt').should(
       'have.attr',
       'data-removed',
       'false'
@@ -161,9 +144,9 @@ describe('Access rights', () => {
   it('submits the new acces rights list without the removed contact', () => {
     const { save } = initialize({});
 
-    cy.findByTestId(`remove-Kathy Schmitt`).click();
+    cy.findByTestId('remove-Kathy Schmitt').click();
 
-    cy.findByTestId(`remove-Kathy Schmitt`).should(
+    cy.findByTestId('remove-Kathy Schmitt').should(
       'have.attr',
       'data-removed',
       'true'
@@ -183,7 +166,8 @@ describe('Access rights', () => {
   it('submits the new acces rights list with the updated contact', () => {
     const { save } = initialize({});
 
-    cy.findByTestId(`role-Kathy Schmitt`).parent().click();
+    cy.findByTestId('remove-Kathy Schmitt').click();
+    cy.findByTestId('role-Kathy Schmitt').parent().click();
 
     cy.get('li[data-value="editor"]').click();
     cy.contains(labels.list.updated).should('be.visible');
@@ -201,7 +185,7 @@ describe('Access rights', () => {
   it('removes the updated chip when the contact role is updated and its initial role is assigned back', () => {
     initialize({});
 
-    cy.findByTestId(`role-Kathy Schmitt`).parent().click();
+    cy.findByTestId('role-Kathy Schmitt').parent().click();
 
     cy.get('li[data-value="editor"]').click();
     cy.contains(labels.list.updated).should('be.visible');
@@ -271,7 +255,7 @@ describe('Access rights', () => {
 
     cy.findByTestId('role-Entity Group 10').should('have.value', 'editor');
     cy.contains(labels.list.added).should('be.visible');
-    cy.contains('1 added').should('be.visible');
+    cy.contains('2 added').should('be.visible');
 
     cy.makeSnapshot();
   });
@@ -284,19 +268,19 @@ describe('Access rights', () => {
 
     cy.waitForRequest('@getContactGroups');
 
-    cy.contains('Entity Group 10').click();
+    cy.contains('Entity Group 11').click();
     cy.findByTestId('add_role').parent().click();
     cy.get('li[data-value="editor"]').click();
     cy.findByTestId('add').click();
 
     cy.contains('Entity Group 10').should('be.visible');
 
-    cy.findByTestId(`role-Kathy Schmitt`).parent().click();
+    cy.findByTestId('role-Kathy Schmitt').parent().click();
     cy.get('li[data-value="editor"]').click();
 
     cy.findByTestId('remove-Linda Schultz').click();
 
-    cy.contains('1 added | 1 updated | 1 removed').should('be.visible');
+    cy.contains('3 added | 1 updated | 1 removed').should('be.visible');
 
     cy.makeSnapshot();
   });
@@ -309,10 +293,10 @@ describe('Access rights', () => {
 
     cy.waitForRequest('@getContacts');
 
-    cy.contains('Entity 10').click();
+    cy.contains('Entity 11').click();
     cy.findByLabelText(labels.add.autocompleteContact).should(
       'have.value',
-      'Entity  10'
+      'Entity  11'
     );
 
     cy.contains(labels.add.contactGroup).click();
@@ -332,18 +316,18 @@ describe('Access rights', () => {
 
     cy.waitForRequest('@getContacts');
 
-    cy.contains('Entity 10').click();
+    cy.contains('Entity 11').click();
 
     cy.findByTestId('add').click();
 
-    cy.contains('Entity 10').should('be.visible');
+    cy.contains('Entity 11').should('be.visible');
 
     cy.contains(labels.list.added).should('be.visible');
 
-    cy.findByTestId('remove-Entity 10').click();
+    cy.findByTestId('remove-Entity 11').click();
 
-    cy.contains('Entity 10').should('not.exist');
-    cy.contains(labels.list.added).should('not.exist');
+    cy.contains('Entity 11').should('not.exist');
+    cy.contains('3 Added').should('not.exist');
 
     cy.makeSnapshot();
   });
@@ -355,7 +339,7 @@ describe('Access rights', () => {
 
     cy.waitForRequest('@getContacts');
 
-    cy.contains('Entity 10').click();
+    cy.contains('Entity 11').click();
 
     cy.findByTestId('add_role').parent().click();
     cy.get('li[data-value="editor"]').click();
@@ -364,10 +348,32 @@ describe('Access rights', () => {
 
     cy.waitForRequest('@getContacts');
 
-    cy.contains('Entity 11').click();
+    cy.contains('Entity 12').click();
 
     cy.findByTestId('add_role').should('have.value', 'viewer');
 
     cy.makeSnapshot();
   });
+
+  it('calls the change function when the corresponding prop is set and the form is updated', () => {
+    const { change } = initialize({});
+
+    cy.contains(labels.add.contact).click();
+    cy.findByLabelText(labels.add.autocompleteContact).click();
+
+    cy.waitForRequest('@getContacts');
+
+    cy.contains('Entity 11').click();
+
+    cy.findByTestId('add').click();
+
+    cy.contains('Entity 11').should('be.visible');
+
+    cy.findByTestId('role-Entity 11').should('have.value', 'viewer');
+    cy.contains(labels.list.added)
+      .should('be.visible')
+      .then(() => {
+        expect(change).to.have.callCount(2);
+      });
+  });
 });
