@@ -232,8 +232,8 @@ class MonitoringServerController extends AbstractController
         } catch (\Exception $ex) {
             $this->error($ex->getMessage());
             throw new MonitoringServerException(
-                'There was an consistency error in the exported files  - please use the legacy export menu to '
-                . 'troubleshoot'
+                'There was an consistency error in the exported files - please use the legacy export menu to troubleshoot',
+                previous: $ex,
             );
         }
     }
