@@ -51,6 +51,11 @@ class CentreonI18nTest extends TestCase
 {
     use Traits\WebServiceAuthorizePublicTrait;
 
+    /** @var Container */
+    public $container;
+    /** @var CentreonI18n|(CentreonI18n&object&\PHPUnit\Framework\MockObject\MockObject)|(CentreonI18n&\PHPUnit\Framework\MockObject\MockObject)|(object&\PHPUnit\Framework\MockObject\MockObject)|\PHPUnit\Framework\MockObject\MockObject */
+    public $webservice;
+
     protected function setUp(): void
     {
         // dependencies
@@ -88,7 +93,7 @@ class CentreonI18nTest extends TestCase
     {
         $this->container->offsetGet(ServiceProvider::CENTREON_I18N_SERVICE)
             ->method('getTranslation')
-            ->will($this->returnCallback(function () {
+            ->will($this->returnCallback(function (): void {
                 throw new \Exception('');
             }));
 
