@@ -51,7 +51,7 @@ abstract class SourceAbstract implements SourceInterface
     /**
      * Construct.
      *
-     * @param \Psr\Container\ContainerInterface $services
+     * @param ContainerInterface $services
      */
     public function __construct(ContainerInterface $services)
     {
@@ -137,14 +137,4 @@ abstract class SourceAbstract implements SourceInterface
 
         return $result;
     }
-
-    /**
-     * @codeCoverageIgnore
-     *
-     * @return string
-     */
-    protected function getPath(): string
-    {
-        return $this->path . static::PATH;
-    }
 }
