@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2024 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * https://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -36,9 +36,10 @@ use Core\Common\Domain\Exception\ValueObjectException;
 use Core\Common\Infrastructure\Repository\DatabaseRepository;
 
 /**
- * Class.
+ * Class
  *
  * @class   DbWriteActionLogRepository
+ * @package Core\ActionLog\Infrastructure\Repository
  */
 class DbWriteActionLogRepository extends DatabaseRepository implements WriteActionLogRepositoryInterface
 {
@@ -48,31 +49,21 @@ class DbWriteActionLogRepository extends DatabaseRepository implements WriteActi
      * @param ActionLog $actionLog
      *
      * @throws RepositoryException
-     *
      * @return int
      */
     public function addAction(ActionLog $actionLog): int
     {
         try {
-            $query = $this->translateDbName(
-                <<<'SQL'
-                    INSERT INTO `:dbstg`.`log_action` (
-                        `action_log_date`,
-                        `object_type`,
-                        `object_id`,
-                        `object_name`,
-                        `action_type`,
-                        `log_contact_id`
-                    ) VALUES (
-                        :creation_date,
-                        :object_type,
-                        :object_id,
-                        :object_name,
-                        :action_type,
-                        :contact_id
-                    )
-                    SQL
-            );
+            $this->queryBuilder->insert('`:dbstg`.log_action')
+                ->values([
+                    'action_log_date' => ':creation_date',
+                    'object_type' => ':object_type',
+                    'object_id' => ':object_id',
+                    'object_name' => ':object_name',
+                    'action_type' => ':action_type',
+                    'log_contact_id' => ':contact_id',
+                ]);
+            $query = $this->translateDbName($this->queryBuilder->getQuery());
 
             $this->connection->insert($query, QueryParameters::create([
                 QueryParameter::int('creation_date', $actionLog->getCreationDate()->getTimestamp()),
@@ -106,6 +97,7 @@ class DbWriteActionLogRepository extends DatabaseRepository implements WriteActi
      * @param array<string,mixed> $details
      *
      * @throws RepositoryException
+     * @return void
      */
     public function addActionDetails(ActionLog $actionLog, array $details): void
     {
