@@ -28,8 +28,8 @@ use Centreon\Domain\Common\Assertion\Assertion;
 
 class NewCommandMacro
 {
-    public const MAX_NAME_LENGTH = 255,
-        MAX_DESCRIPTION_LENGTH = 65535;
+    public const MAX_NAME_LENGTH = 255;
+    public const MAX_DESCRIPTION_LENGTH = 65535;
 
     private string $shortName;
 
