@@ -27,8 +27,8 @@ use Centreon\Domain\Common\Assertion\Assertion;
 
 class UserGroup
 {
-    public const MAX_NAME_LENGTH = 200,
-                 MAX_ALIAS_LENGTH = 200;
+    public const MAX_NAME_LENGTH = 200;
+    public const MAX_ALIAS_LENGTH = 200;
 
     /**
      * @param int $id
