@@ -24,6 +24,7 @@ declare(strict_types = 1);
 namespace Core\Media\Infrastructure\Repository;
 
 use Core\Media\Application\Repository\WriteMediaRepositoryInterface;
+use Core\Media\Domain\Model\Media;
 use Core\Media\Domain\Model\NewMedia;
 
 class FileProxyWriteMediaRepository implements WriteMediaRepositoryInterface
@@ -34,6 +35,15 @@ class FileProxyWriteMediaRepository implements WriteMediaRepositoryInterface
     ) {
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function update(Media $media): void
+    {
+        $this->dbWriteMediaRepository->update($media);
+        $this->fileWriteMediaRepository->update($media);
+    }
+
     /**
      * Creates the file in the directory after it has been saved in the databases.
      *
@@ -46,4 +56,15 @@ class FileProxyWriteMediaRepository implements WriteMediaRepositoryInterface
 
         return $mediaId;
     }
+
+    /**
+     * Deletes the file from the database and also from the file system.
+     *
+     * {@inheritDoc}
+     */
+    public function delete(Media $media): void
+    {
+        $this->dbWriteMediaRepository->delete($media);
+        $this->fileWriteMediaRepository->delete($media);
+    }
 }
