@@ -47,6 +47,27 @@ interface ReadMonitoringServerRepositoryInterface {
      */
     public function existsByAccessGroups(int $monitoringServerId, array $accessGroups): bool;
 
+    /**
+     * Determine if monitoring servers exist by their IDs.
+     * Return the ids found.
+     *
+     * @param int[] $monitoringServerIds
+     *
+     * @return int[]
+     */
+    public function exist(array $monitoringServerIds): array;
+
+    /**
+     * Determine if monitoring servers exist by their IDs and access groups.
+     * Return the ids found.
+     *
+     * @param int[] $monitoringServerIds
+     * @param AccessGroup[] $accessGroups
+     *
+     * @return int[]
+     */
+    public function existByAccessGroups(array $monitoringServerIds, array $accessGroups): array;
+
     /**
      * Get a monitoring server by its associated host ID.
      *
@@ -78,7 +99,6 @@ interface ReadMonitoringServerRepositoryInterface {
      * @param int $monitoringServerId
      *
      * @throws EntityNotFoundException when no Monitoring server are found
-     *
      * @return MonitoringServer
      */
     public function get(int $monitoringServerId): MonitoringServer;
