@@ -32,4 +32,14 @@ class ResourceException extends \Exception
     {
         return new self(_('Error while searching for resources'));
     }
+
+    public static function errorWhileFindingHostsStatusCount(): self
+    {
+        return new self(_('Error while retrieving the number of hosts by status'));
+    }
+
+    public static function errorWhileFindingServicesStatusCount(): self
+    {
+        return new self(_('Error while retrieving the number of services by status'));
+    }
 }
